@@ -22,12 +22,13 @@ def get_json(user, repl):
 	'''
 	return requests.get(f'https://replit.com/data/repls/@{user}/{repl}').json()
 
-def get_token(name, key):
+def get_token(name, repl, key):
 	'''
 	get_token(id: str, key: str)
 	Given a repl ID and an API key, get a one-time token for that repl.
 	'''
 	headers = {
+		'Content-Type': 'application/json',
 		'connect.sid': key,
 		'X-Requested-With': 'https://replit.com',
 		'Origin': 'https://replit.com',
@@ -36,8 +37,8 @@ def get_token(name, key):
 	cookies = {
 		'connect.sid': key
 	}
-	r = requests.get(f'https://replit.com/@{name}', headers=headers, cookies=cookies)
-	data = json.loads(r.text.split("<script id=\"__NEXT_DATA__\" type=\"application/json\">")[1].split("</script>")[0])['props']['pageProps']['connectionMetadata']['
+	r = requests.get(f'https://replit.com/@{name}/{repl}', headers=headers, cookies=cookies)
+	data = json.loads(r.text.split("<script id=\"__NEXT_DATA__\" type=\"application/json\">")[1].split("</script>")[0])['props']['pageProps']['connectionMetadata']
 	return data['token'], f"{data['gurl']}/wsv2/{data['token']}"
 
 class PyReplError(Exception):
